function varargout = counter(varargin)
% COUNTER MATLAB code for counter.fig
%      COUNTER, by itself, creates a new COUNTER or raises the existing
%      singleton*.
%
%      H = COUNTER returns the handle to a new COUNTER or the handle to
%      the existing singleton*.
%
%      COUNTER('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in COUNTER.M with the given input arguments.
%
%      COUNTER('Property','Value',...) creates a new COUNTER or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before counter_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to counter_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help counter

% Last Modified by GUIDE v2.5 22-Nov-2018 02:01:05

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @counter_OpeningFcn, ...
                   'gui_OutputFcn',  @counter_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before counter is made visible.
function counter_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to counter (see VARARGIN)

% Choose default command line output for counter
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes counter wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = counter_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
a=1;
while a==0
end
promenna=1;
switch promenna
    case 0
        disp('nula');
    case 5
        disp('pet');    
end
str2num('a');
num2str(5);
o=[4,5,6];
p=fft(o);
m=ifft(p);
length(p);
length(o);
length(m);
sum(a,o);
max(a,o);
min(p,m);
mean(p,a);

% --- Executes on button press in btnPlus.
function btnPlus_Callback(hObject, eventdata, handle)
aktualni = str2num(get(handle.display,'String'));
set(handle.display,'String',num2str(aktualni+1));
o=[4,5,6];
p=fft(o);
m=ifft(p);
% --- Executes on button press in btnMinus.
function btnMinus_Callback(hObject, eventdata, handles)
aktualni = str2num(get(handles.display,'String'));
set(handles.display,'String',num2str(aktualni-1)); 




% --- Executes on button press in btnReset.
function btnReset_Callback(hObject, eventdata, handles)
set(handles.display,'String','0');

